pub enum ChangesetState {
Draft,
Submitted,
Verifying,
Approved,
Rejected,
Merged,
Closed,
}Expand description
Explicit changeset states. Replaces the former ambiguous “open” state.
Variants
Implementations
Sourceimpl ChangesetState
impl ChangesetState
Sourcepub fn parse(s: &str) -> Option<Self>
pub fn parse(s: &str) -> Option<Self>
Parse a state string from the database into a ChangesetState.
Sourcepub fn can_transition_to(&self, target: Self) -> bool
pub fn can_transition_to(&self, target: Self) -> bool
Check whether transitioning from self to target is valid.
Valid transitions:
- draft -> submitted
- submitted -> verifying
- verifying -> approved | rejected
- approved -> merged
- any -> closed