Module git

Module git 

Structs

GitObjects
Provides read/write access to Git objects (blobs) and working tree files through a borrowed reference to a super::GitRepository.
GitRepository
A wrapper around gix::Repository providing a simplified interface for Git repository operations.