pub struct Changeset {Show 18 fields
pub id: Uuid,
pub repo_id: RepoId,
pub number: i32,
pub title: String,
pub intent_summary: Option<String>,
pub source_branch: String,
pub target_branch: String,
pub state: String,
pub reason: String,
pub session_id: Option<Uuid>,
pub agent_id: Option<String>,
pub agent_name: Option<String>,
pub author_id: Option<Uuid>,
pub base_version: Option<String>,
pub merged_version: Option<String>,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
pub merged_at: Option<DateTime<Utc>>,
}Fields
id: Uuidrepo_id: RepoIdnumber: i32title: Stringintent_summary: Option<String>source_branch: Stringtarget_branch: Stringstate: Stringreason: Stringsession_id: Option<Uuid>agent_id: Option<String>agent_name: Option<String>base_version: Option<String>merged_version: Option<String>created_at: DateTime<Utc>updated_at: DateTime<Utc>merged_at: Option<DateTime<Utc>>Implementations
Sourceimpl Changeset
impl Changeset
Sourcepub fn parsed_state(&self) -> Option<ChangesetState>
pub fn parsed_state(&self) -> Option<ChangesetState>
Parse the current state string into a typed ChangesetState.
Sourcepub fn transition(
&mut self,
target: ChangesetState,
reason: impl Into<String>,
) -> Result<()>
pub fn transition( &mut self, target: ChangesetState, reason: impl Into<String>, ) -> Result<()>
Validate and perform a state transition, recording the reason. Returns an error if the transition is not allowed.